pub struct ConnectionErrors(pub Vec<(SocketAddr, Error)>);Expand description
A sequence of errors which occurred during a connection attempt.
These are paired with a SocketAddr because the connection attempt might fail multiple times
during DNS resolution.
Tuple Fields
0: Vec<(SocketAddr, Error)>Trait Implementations