pub struct ConnectionHandle<A, Conn> { /* private fields */ }
Provides an interface for connecting (and reconnecting) to Graylog. Without an established connection logs will not be sent. Messages logged without an established connection will sit in the buffer until they can be drained.

Implementations

Returns the connection address.

Connects to Graylog via TCP using the address provided.

This will perform DNS resolution and attempt to connect to each SocketAddr provided.

Connects to Graylog via UDP using the address provided.

This will perform DNS resolution and attempt to connect to each SocketAddr provided.