Struct tracing_gelf::ConnectionHandle
source · [−]pub struct ConnectionHandle<A, Conn> { /* private fields */ }Expand description
Provides an interface for connecting (and reconnecting) to Graylog. Without an established connection logs will not be sent. Messages logged without an established connection will sit in the buffer until they can be drained.
Implementations
sourceimpl<A, Conn> ConnectionHandle<A, Conn>
impl<A, Conn> ConnectionHandle<A, Conn>
sourceimpl<A> ConnectionHandle<A, TcpConnection> where
A: ToSocketAddrs,
impl<A> ConnectionHandle<A, TcpConnection> where
A: ToSocketAddrs,
sourcepub async fn connect(&mut self) -> ConnectionErrors
pub async fn connect(&mut self) -> ConnectionErrors
Connects to Graylog via TCP using the address provided.
This will perform DNS resolution and attempt to connect to each SocketAddr provided.
sourceimpl<A> ConnectionHandle<A, UdpConnection> where
A: ToSocketAddrs,
impl<A> ConnectionHandle<A, UdpConnection> where
A: ToSocketAddrs,
sourcepub async fn connect(&mut self) -> ConnectionErrors
pub async fn connect(&mut self) -> ConnectionErrors
Connects to Graylog via UDP using the address provided.
This will perform DNS resolution and attempt to connect to each SocketAddr provided.